@@ -324,7 +324,7 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	remotedatavbox = gtk_vbox_new (FALSE, 0);
 	gtk_container_add (GTK_CONTAINER (remotedataframe), remotedatavbox);
 	remotedatalabel = gtk_label_new
-		(_("When receiving data from another application (gmfsk, ktrack):"));
+		(_("When receiving data from another application (gmfsk, ktrack, fldigi, wsjt-x):"));
 	gtk_box_pack_start
 		(GTK_BOX (remotedatavbox), remotedatalabel, FALSE, FALSE, 0);
 	gtk_label_set_line_wrap (GTK_LABEL (remotedatalabel), TRUE);
@@ -473,6 +473,8 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	  g_dir_close(dev_serial_dir);
 	}
 
+	gtk_combo_box_append_text (GTK_COMBO_BOX (devicecombo), "/dev/ttyUSB0");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (devicecombo), "/dev/ttyUSB1");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (devicecombo), "/dev/ttyS0");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (devicecombo), "/dev/ttyS1");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (devicecombo), "/dev/ttyS2");
