@@ -167,6 +167,7 @@ edi_qso_append (LOGDB * handle, const qso_t * q)
 {
 	FILE *fp = (FILE *) handle->priv;
 	gchar rst[16], exch[16] = "", my_rst[16], my_exch[16] = "";
+	gchar *q_mode = q[MODE] ? q[MODE] : "SSB";
 	gchar *p;
 	gchar *temp;
 	struct tm tm_a;
@@ -177,17 +178,35 @@ edi_qso_append (LOGDB * handle, const qso_t * q)
 	 * there's no exchange fields in xlog. However, the exchange information
 	 * may be piggybacked by the rst field. eg. "599 35".
 	 */
-	p = strchr (q[RST], ' ');
-	rst_len = p ? p - q[RST] : strlen (q[RST]);
 
-	strncpy (rst, q[RST], rst_len);
-	rst[rst_len] = '\0';
-	strncpy (my_rst, q[MYRST], rst_len);
-	my_rst[rst_len] = '\0';
-	if (strlen (q[RST]) > rst_len)
+    if ((q[RST] != NULL) && (q[MYRST] != NULL)) {
+
+	  p = strchr (q[RST], ' ');
+	  rst_len = p ? p - q[RST] : strlen (q[RST]);
+
+	  strncpy (rst, q[RST], rst_len);
+	  rst[rst_len] = '\0';
+	  strncpy (my_rst, q[MYRST], rst_len);
+	  my_rst[rst_len] = '\0';
+	  if (strlen (q[RST]) > rst_len)
 		strcpy (exch, q[RST] + rst_len + 1);
-	if (strlen (q[MYRST]) > rst_len)
+	  if (strlen (q[MYRST]) > rst_len)
 		strcpy (my_exch, q[MYRST] + rst_len + 1);
+	} else {
+
+	  if (!strcmp (q_mode, "SSB") || !strcmp (q_mode, "USB")
+		  || !strcmp (q_mode, "LSB") || !strcmp (q_mode, "FM"))
+		rst_len = 2;
+	  else
+		rst_len = 3;
+
+	  strncpy(rst, "599", rst_len);
+	  rst[rst_len] = '\0';
+
+	  strncpy(my_rst, "599", rst_len);
+	  my_rst[rst_len] = '\0';
+	  
+	}
 
 	/* YYMMDD */
 	gchar date[32];
